==> rflowcyt_1.6.0.tar.gz: rflowcyt/R/plot2sets.FCS.R <==
plot2sets.FCS<- function(data1,data2,varpos=c(1),FUN,nrow=8,ncol=12,ind=c(1:96),col="row",labeling=TRUE,...){


    if((!is(data1, "cytoSet")) && (!is(data1[[1]],"FCS"))){
        stop("input 'object' must be a cytoSet object or a list of FCS objects")
    }
    if((is(data1, "cytoSet")) && (!is(data2, "cytoSet"))){
        stop("input 'objects' must be of same class either 2 lists of FCS objects or 2 cytosets")
    }
    if((is(data1[[1]], "FCS")) && (!is(data2, "FCS"))){
        stop("input 'objects' must be of same class either 2 lists of FCS objects or 2 cytosets")
    }
    if(length(varpos)!=1){
        stop("input 'varpos' must be a vector of length 1")
    }
    if((col!="row") && (col!="col")){
        stop("input 'color' must either be by 'row' or by 'col'")
    }
    
    colori <- colors()[c(24,27,41,48,56,69,76,84,91,116,126,139)]

      if(class(data1)=="cytoSet"){
          fichier1 <- as.character(phenoData(data1)$name)
          fichier2 <- as.character(phenoData(data2)$name)
      }
      else{
          fichier1 <- names(data1)
          fichier2 <- names(data2)
      }
    
    if(any(fichier1!=fichier2))
      stop("Different file names, objects not comparable.")
    
    FUN <- match.fun(FUN)
    dat1 <- dat2 <- list()

    if(is(data1,"cytoSet") && is(data2,"cytoSet")){    
        for(i in 1:length(cyto1))  dat1[[i]] <- exprs(data1[[i]])
        for(j in 1:length(cyto2))  dat2[[j]] <- exprs(data2[[j]])
    }
    if(is(data1[[1]],"FCS") && is(data2[[1]])){
        dat1 <-lapply (data1,fluors)
        dat2 <-lapply(data2,fluors)
    }

    names(dat1) <- fichier1
    names(dat2) <- fichier1

    x <-y <- vector(mode="numeric",length=96)

    x <-  unlist(lapply(dat1,function(z) FUN(z[,varpos])))
    y <-  unlist(lapply(dat2,function(z) FUN(z[,varpos])))

    if(col=="row") {
        color <- rep(colori[1:nrow],each=ncol)
        col.leg <-colori[1:nrow]
        text.title <- "by row"
        text.leg <- c(1:nrow)
    }
    if(col=="col") {
        color <-rep(colori[1:ncol],times=nrow)
        col.leg <-colori[1:ncol]
        text.title <- "by column"
        text.leg <- c(1:ncol)
    }
    
    nbwell <- nrow*ncol
    indwell <- 1:nbwell
    if(length(ind)!=nbwell) {
        color <- color[indwell%in%ind]
    }
    
    plot(x,y,col=color,type="p",...)
    if(labeling) {
        text(x+.4,y+.4,as.character(fichier1),cex=0.5)
    }
}

==> rflowcyt_1.16.0.tar.gz: rflowcyt/R/plot2sets.FCS.R <==
plot2sets.FCS<- function(data1, data2, varpos=c(1), FUN, nrow=8, ncol=12, ind=c(1:96), col="row", labeling=TRUE,...){


    if((!is(data1, "cytoSet")) && (!is(data1[[1]],"FCS"))){
        stop("input 'object' must be a cytoSet object or a list of FCS objects")
    }
    if((is(data1, "cytoSet")) && (!is(data2, "cytoSet"))){
        stop("input 'objects' must be of same class either 2 lists of FCS objects or 2 cytosets")
    }
    if((is(data1[[1]], "FCS")) && (!is(data2, "FCS"))){
        stop("input 'objects' must be of same class either 2 lists of FCS objects or 2 cytosets")
    }
    if(length(varpos)!=1){
        stop("input 'varpos' must be a vector of length 1")
    }
    if((col!="row") && (col!="col")){
        stop("input 'color' must either be by 'row' or by 'col'")
    }
    
    colori <- colors()[c(24,27,41,48,56,69,76,84,91,116,126,139)]

      if(class(data1)=="cytoSet"){
          fichier1 <- as.character(phenoData(data1)$name)
          fichier2 <- as.character(phenoData(data2)$name)
      }
      else{
          fichier1 <- names(data1)
          fichier2 <- names(data2)
      }
    
    if(any(fichier1!=fichier2))
      stop("Different file names, objects not comparable.")
    
    FUN <- match.fun(FUN)
    dat1 <- dat2 <- list()

    if(is(data1,"cytoSet") && is(data2,"cytoSet")){    
        for(i in 1:length(data1))  dat1[[i]] <- exprs(data1[[i]])
        for(j in 1:length(data2))  dat2[[j]] <- exprs(data2[[j]])
    }
    if(is(data1[[1]],"FCS") && is(data2[[1]])){
        dat1 <-lapply (data1,fluors)
        dat2 <-lapply(data2,fluors)
    }

    names(dat1) <- fichier1
    names(dat2) <- fichier1

    x <-y <- vector(mode="numeric",length=96)

    x <-  unlist(lapply(dat1,function(z) FUN(z[,varpos])))
    y <-  unlist(lapply(dat2,function(z) FUN(z[,varpos])))

    if(col=="row") {
        color <- rep(colori[1:nrow],each=ncol)
        col.leg <-colori[1:nrow]
        text.title <- "by row"
        text.leg <- c(1:nrow)
    }
    if(col=="col") {
        color <-rep(colori[1:ncol],times=nrow)
        col.leg <-colori[1:ncol]
        text.title <- "by column"
        text.leg <- c(1:ncol)
    }
    
    nbwell <- nrow*ncol
    indwell <- 1:nbwell
    if(length(ind)!=nbwell) {
        color <- color[indwell%in%ind]
    }
    
    plot(x,y,col=color,type="p",...)
    if(labeling) {
        text(x+.4,y+.4,as.character(fichier1),cex=0.5)
    }
}
